@@ -1,7 +1,7 @@
 // synthv1.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
 
 // forward declarations
 class synthv1_impl;
+class synthv1_port;
 class synthv1_controls;
 class synthv1_programs;
 
@@ -50,6 +51,12 @@ public:
 	void setSampleRate(float srate);
 	float sampleRate() const;
 
+	void setBufferSize(uint32_t nsize);
+	uint32_t bufferSize() const;
+
+	void setTempo(float bpm);
+	float tempo() const;
+
 	enum ParamIndex	 {
 
 		DCO1_SHAPE1 = 0,
@@ -61,6 +68,7 @@ public:
 		DCO1_BALANCE,
 		DCO1_DETUNE,
 		DCO1_PHASE,
+		DCO1_RINGMOD,
 		DCO1_OCTAVE,
 		DCO1_TUNING,
 		DCO1_GLIDE,
@@ -76,9 +84,12 @@ public:
 		DCF1_RELEASE,
 		LFO1_SHAPE,
 		LFO1_WIDTH,
+		LFO1_BPM,
 		LFO1_RATE,
+		LFO1_SYNC,
 		LFO1_SWEEP,
 		LFO1_PITCH,
+		LFO1_RINGMOD,
 		LFO1_CUTOFF,
 		LFO1_RESO,
 		LFO1_PANNING,
@@ -94,6 +105,7 @@ public:
 		DCA1_RELEASE,
 		OUT1_WIDTH,
 		OUT1_PANNING,
+		OUT1_FXSEND,
 		OUT1_VOLUME,
 
 		DEF1_PITCHBEND,
@@ -112,6 +124,7 @@ public:
 		DCO2_BALANCE,
 		DCO2_DETUNE,
 		DCO2_PHASE,
+		DCO2_RINGMOD,
 		DCO2_OCTAVE,
 		DCO2_TUNING,
 		DCO2_GLIDE,
@@ -127,9 +140,12 @@ public:
 		DCF2_RELEASE,
 		LFO2_SHAPE,
 		LFO2_WIDTH,
+		LFO2_BPM,
 		LFO2_RATE,
+		LFO2_SYNC,
 		LFO2_SWEEP,
 		LFO2_PITCH,
+		LFO2_RINGMOD,
 		LFO2_CUTOFF,
 		LFO2_RESO,
 		LFO2_PANNING,
@@ -145,6 +161,7 @@ public:
 		DCA2_RELEASE,
 		OUT2_WIDTH,
 		OUT2_PANNING,
+		OUT2_FXSEND,
 		OUT2_VOLUME,
 
 		DEF2_PITCHBEND,
@@ -172,8 +189,6 @@ public:
 		DEL1_DELAY,
 		DEL1_FEEDB,
 		DEL1_BPM,
-		DEL1_BPMSYNC,
-		DEL1_BPMHOST,
 		REV1_WET,
 		REV1_ROOM,
 		REV1_DAMP,
@@ -186,7 +201,7 @@ public:
 	};
 
 	void setParamPort(ParamIndex index, float *pfParam);
-	float *paramPort(ParamIndex index) const;
+	synthv1_port *paramPort(ParamIndex index) const;
 
 	synthv1_controls *controls() const;
 	synthv1_programs *programs() const;
