@@ -1,7 +1,7 @@
 // synthv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -104,7 +104,7 @@ private:
 
 
 //-------------------------------------------------------------------------
-// jack process callback.
+// JACK process callback.
 
 static
 int synthv1_jack_process ( jack_nframes_t nframes, void *arg )
@@ -113,6 +113,16 @@ int synthv1_jack_process ( jack_nframes_t nframes, void *arg )
 }
 
 
+//----------------------------------------------------------------------
+// JACK buffer-size change callback.
+
+static int synthv1_jack_buffer_size ( jack_nframes_t nframes, void *arg )
+{
+	static_cast<synthv1_jack *> (arg)->setBufferSize(nframes);
+
+	return 0;
+}
+
 
 #ifdef CONFIG_JACK_SESSION
 
@@ -165,8 +175,6 @@ synthv1_jack::synthv1_jack (void) : synthv1(2)
 	m_alsa_thread  = NULL;
 #endif
 
-	m_bpm = 0.0f;
-
 	synthv1::programs()->enabled(true);
 	synthv1::controls()->enabled(true);
 
@@ -202,18 +210,12 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 			::jack_port_get_buffer(m_audio_outs[k], nframes));
 	}
 
-	const float bpm_sync = paramValue(synthv1::DEL1_BPMSYNC);
-	if (bpm_sync > 0.0f) {
-		const float bpm_host = paramValue(synthv1::DEL1_BPMHOST);
-		if (bpm_host > 0.0f) {
-			jack_position_t pos;
-			jack_transport_query(m_client, &pos);
-			if (pos.valid & JackPositionBBT) {
-				const float bpm = float(pos.beats_per_minute);
-				if (::fabs(bpm_host - bpm) > 0.01f)
-					setParamValue(synthv1::DEL1_BPMHOST, bpm);
-			}
-		}
+	jack_position_t pos;
+	jack_transport_query(m_client, &pos);
+	if (pos.valid & JackPositionBBT) {
+		const float host_bpm = float(pos.beats_per_minute);
+		if (::fabsf(host_bpm - synthv1::tempo()) > 0.001f)
+			synthv1::setTempo(host_bpm);
 	}
 
 	uint32_t ndelta = 0;
@@ -225,12 +227,14 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 		for (uint32_t n = 0; n < nevents; ++n) {
 			jack_midi_event_t event;
 			::jack_midi_event_get(&event, midi_in, n);
-			uint32_t nread = event.time - ndelta;
-			if (nread > 0) {
-				synthv1::process(ins, outs, nread);
-				for (uint16_t k = 0; k < nchannels; ++k) {
-					ins[k]  += nread;
-					outs[k] += nread;
+			if (event.time > ndelta) {
+				const uint32_t nread = event.time - ndelta;
+				if (nread > 0) {
+					synthv1::process(ins, outs, nread);
+					for (uint16_t k = 0; k < nchannels; ++k) {
+						ins[k]  += nread;
+						outs[k] += nread;
+					}
 				}
 			}
 			ndelta = event.time;
@@ -269,7 +273,8 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 	}
 #endif // CONFIG_ALSA_MIDI
 
-	synthv1::process(ins, outs, nframes - ndelta);
+	if (nframes > ndelta)
+		synthv1::process(ins, outs, nframes - ndelta);
 
 	return 0;
 }
@@ -341,6 +346,12 @@ void synthv1_jack::open ( const char *client_id )
 	}
 #endif	// CONFIG_ALSA_MIDI
 
+	// setup any local, initial buffers...
+	synthv1::setBufferSize(::jack_get_buffer_size(m_client));
+
+	jack_set_buffer_size_callback(m_client,
+		synthv1_jack_buffer_size, this);
+
 	// set process callbacks...
 	::jack_set_process_callback(m_client,
 		synthv1_jack_process, this);
@@ -457,17 +468,6 @@ void synthv1_jack::close (void)
 }
 
 
-void synthv1_jack::setParamValue ( synthv1::ParamIndex index, float fValue )
-{
-	m_params[index] = fValue;
-}
-
-float synthv1_jack::paramValue ( synthv1::ParamIndex index ) const
-{
-	return m_params[index];
-}
-
-
 #ifdef CONFIG_ALSA_MIDI
 
 // alsa sequencer client.
@@ -697,11 +697,11 @@ bool synthv1_jack_application::setup (void)
 
 	if (m_bGui) {
 		m_pWidget = new synthv1widget_jack(m_pSynth);
+		m_pWidget->show();
 		if (m_presets.isEmpty())
 			m_pWidget->initPreset();
 		else
 			m_pWidget->loadPreset(m_presets.first());
-		m_pWidget->show();
 	}
 	else
 	if (!m_presets.isEmpty())
