@@ -1,7 +1,7 @@
 // synthv1_jack.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -57,9 +57,6 @@ public:
 
 	int process(jack_nframes_t nframes);
 
-	void setParamValue(synthv1::ParamIndex index, float fValue);
-	float paramValue(synthv1::ParamIndex index) const;
-
 #ifdef CONFIG_ALSA_MIDI
 	snd_seq_t *alsa_seq() const;
 	void alsa_capture(snd_seq_event_t *ev);
@@ -95,8 +92,6 @@ private:
 	jack_ringbuffer_t *m_alsa_buffer;
 	synthv1_alsa_thread *m_alsa_thread;
 #endif
-
-	float m_bpm;
 };
 
 
