@@ -1,7 +1,7 @@
 // synthv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -114,6 +114,8 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	QStringList slopes;
 	slopes << tr("12dB/oct");
 	slopes << tr("24dB/oct");
+	slopes << tr("Biquad");
+	slopes << tr("Formant");
 
 	m_ui.Dcf1SlopeKnob->insertItems(0, slopes);
 	m_ui.Dcf2SlopeKnob->insertItems(0, slopes);
@@ -128,11 +130,18 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Dco2Bandl1Knob->insertItems(0, states);
 	m_ui.Dco2Bandl2Knob->insertItems(0, states);
 
+	m_ui.Lfo1SyncKnob->insertItems(0, states);
+	m_ui.Lfo2SyncKnob->insertItems(0, states);
+
 	m_ui.Dyn1CompressKnob->insertItems(0, states);
 	m_ui.Dyn1LimiterKnob->insertItems(0, states);
 
 	// Special values
 	const QString& sOff = states.first();
+	m_ui.Dco1RingModKnob->setSpecialValueText(sOff);
+	m_ui.Dco2RingModKnob->setSpecialValueText(sOff);
+	m_ui.Dco1GlideKnob->setSpecialValueText(sOff);
+	m_ui.Dco2GlideKnob->setSpecialValueText(sOff);
 	m_ui.Cho1WetKnob->setSpecialValueText(sOff);
 	m_ui.Fla1WetKnob->setSpecialValueText(sOff);
 	m_ui.Pha1WetKnob->setSpecialValueText(sOff);
@@ -140,6 +149,8 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Rev1WetKnob->setSpecialValueText(sOff);
 
 	const QString& sAuto = tr("Auto");
+	m_ui.Lfo1BpmKnob->setSpecialValueText(sAuto);
+	m_ui.Lfo2BpmKnob->setSpecialValueText(sAuto);
 	m_ui.Del1BpmKnob->setSpecialValueText(sAuto);
 
 	// Wave integer widths.
@@ -180,6 +191,10 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Dcf2EnvelopeKnob->setMaximum(+1.0f);
 
 	// LFO parameter limits.
+	m_ui.Lfo1BpmKnob->setScale(1.0f);
+	m_ui.Lfo1BpmKnob->setMinimum(0.0f);
+	m_ui.Lfo1BpmKnob->setMaximum(360.0f);
+	m_ui.Lfo1BpmKnob->setSingleStep(1.0f);
 	m_ui.Lfo1SweepKnob->setMinimum(-1.0f);
 	m_ui.Lfo1SweepKnob->setMaximum(+1.0f);
 	m_ui.Lfo1CutoffKnob->setMinimum(-1.0f);
@@ -188,11 +203,17 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Lfo1ResoKnob->setMaximum(+1.0f);
 	m_ui.Lfo1PitchKnob->setMinimum(-1.0f);
 	m_ui.Lfo1PitchKnob->setMaximum(+1.0f);
+	m_ui.Lfo1RingModKnob->setMinimum(-1.0f);
+	m_ui.Lfo1RingModKnob->setMaximum(+1.0f);
 	m_ui.Lfo1PanningKnob->setMinimum(-1.0f);
 	m_ui.Lfo1PanningKnob->setMaximum(+1.0f);
 	m_ui.Lfo1VolumeKnob->setMinimum(-1.0f);
 	m_ui.Lfo1VolumeKnob->setMaximum(+1.0f);
 
+	m_ui.Lfo2BpmKnob->setScale(1.0f);
+	m_ui.Lfo2BpmKnob->setMinimum(0.0f);
+	m_ui.Lfo2BpmKnob->setMaximum(360.0f);
+	m_ui.Lfo2BpmKnob->setSingleStep(1.0f);
 	m_ui.Lfo2SweepKnob->setMinimum(-1.0f);
 	m_ui.Lfo2SweepKnob->setMaximum(+1.0f);
 	m_ui.Lfo2CutoffKnob->setMinimum(-1.0f);
@@ -201,11 +222,14 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Lfo2ResoKnob->setMaximum(+1.0f);
 	m_ui.Lfo2PitchKnob->setMinimum(-1.0f);
 	m_ui.Lfo2PitchKnob->setMaximum(+1.0f);
+	m_ui.Lfo2RingModKnob->setMinimum(-1.0f);
+	m_ui.Lfo2RingModKnob->setMaximum(+1.0f);
 	m_ui.Lfo2PanningKnob->setMinimum(-1.0f);
 	m_ui.Lfo2PanningKnob->setMaximum(+1.0f);
 	m_ui.Lfo2VolumeKnob->setMinimum(-1.0f);
 	m_ui.Lfo2VolumeKnob->setMaximum(+1.0f);
 
+
 	// Channel filters
 	QStringList channels;
 	channels << tr("Omni");
@@ -235,7 +259,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 
 	// Effects (delay BPM)
 	m_ui.Del1BpmKnob->setScale(1.0f);
-	m_ui.Del1BpmKnob->setMinimum(3.6f);
+	m_ui.Del1BpmKnob->setMinimum(0.0f);
 	m_ui.Del1BpmKnob->setMaximum(360.0f);
 	m_ui.Del1BpmKnob->setSingleStep(1.0f);
 
@@ -253,6 +277,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DCO1_BALANCE, m_ui.Dco1BalanceKnob);
 	setParamKnob(synthv1::DCO1_DETUNE,  m_ui.Dco1DetuneKnob);
 	setParamKnob(synthv1::DCO1_PHASE,   m_ui.Dco1PhaseKnob);
+	setParamKnob(synthv1::DCO1_RINGMOD, m_ui.Dco1RingModKnob);
 	setParamKnob(synthv1::DCO1_OCTAVE,  m_ui.Dco1OctaveKnob);
 	setParamKnob(synthv1::DCO1_TUNING,  m_ui.Dco1TuningKnob);
 	setParamKnob(synthv1::DCO1_GLIDE,   m_ui.Dco1GlideKnob);
@@ -347,12 +372,15 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// LFO1
 	setParamKnob(synthv1::LFO1_SHAPE,   m_ui.Lfo1ShapeKnob);
 	setParamKnob(synthv1::LFO1_WIDTH,   m_ui.Lfo1WidthKnob);
+	setParamKnob(synthv1::LFO1_BPM,     m_ui.Lfo1BpmKnob);
 	setParamKnob(synthv1::LFO1_RATE,    m_ui.Lfo1RateKnob);
+	setParamKnob(synthv1::LFO1_SYNC,    m_ui.Lfo1SyncKnob);
 	setParamKnob(synthv1::LFO1_PANNING, m_ui.Lfo1PanningKnob);
 	setParamKnob(synthv1::LFO1_VOLUME,  m_ui.Lfo1VolumeKnob);
 	setParamKnob(synthv1::LFO1_CUTOFF,  m_ui.Lfo1CutoffKnob);
 	setParamKnob(synthv1::LFO1_RESO,    m_ui.Lfo1ResoKnob);
 	setParamKnob(synthv1::LFO1_PITCH,   m_ui.Lfo1PitchKnob);
+	setParamKnob(synthv1::LFO1_RINGMOD, m_ui.Lfo1RingModKnob);
 	setParamKnob(synthv1::LFO1_SWEEP,   m_ui.Lfo1SweepKnob);
 	setParamKnob(synthv1::LFO1_ATTACK,  m_ui.Lfo1AttackKnob);
 	setParamKnob(synthv1::LFO1_DECAY,   m_ui.Lfo1DecayKnob);
@@ -446,6 +474,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// OUT1
 	setParamKnob(synthv1::OUT1_WIDTH,   m_ui.Out1WidthKnob);
 	setParamKnob(synthv1::OUT1_PANNING, m_ui.Out1PanningKnob);
+	setParamKnob(synthv1::OUT1_FXSEND,  m_ui.Out1FxSendKnob);
 	setParamKnob(synthv1::OUT1_VOLUME,  m_ui.Out1VolumeKnob);
 
 
@@ -459,6 +488,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DCO2_BALANCE, m_ui.Dco2BalanceKnob);
 	setParamKnob(synthv1::DCO2_DETUNE,  m_ui.Dco2DetuneKnob);
 	setParamKnob(synthv1::DCO2_PHASE,   m_ui.Dco2PhaseKnob);
+	setParamKnob(synthv1::DCO2_RINGMOD, m_ui.Dco2RingModKnob);
 	setParamKnob(synthv1::DCO2_OCTAVE,  m_ui.Dco2OctaveKnob);
 	setParamKnob(synthv1::DCO2_TUNING,  m_ui.Dco2TuningKnob);
 	setParamKnob(synthv1::DCO2_GLIDE,   m_ui.Dco2GlideKnob);
@@ -553,12 +583,15 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// LFO2
 	setParamKnob(synthv1::LFO2_SHAPE,   m_ui.Lfo2ShapeKnob);
 	setParamKnob(synthv1::LFO2_WIDTH,   m_ui.Lfo2WidthKnob);
+	setParamKnob(synthv1::LFO2_BPM,     m_ui.Lfo2BpmKnob);
 	setParamKnob(synthv1::LFO2_RATE,    m_ui.Lfo2RateKnob);
+	setParamKnob(synthv1::LFO2_SYNC,    m_ui.Lfo2SyncKnob);
 	setParamKnob(synthv1::LFO2_PANNING, m_ui.Lfo2PanningKnob);
 	setParamKnob(synthv1::LFO2_VOLUME,  m_ui.Lfo2VolumeKnob);
 	setParamKnob(synthv1::LFO2_CUTOFF,  m_ui.Lfo2CutoffKnob);
 	setParamKnob(synthv1::LFO2_RESO,    m_ui.Lfo2ResoKnob);
 	setParamKnob(synthv1::LFO2_PITCH,   m_ui.Lfo2PitchKnob);
+	setParamKnob(synthv1::LFO2_RINGMOD, m_ui.Lfo2RingModKnob);
 	setParamKnob(synthv1::LFO2_SWEEP,   m_ui.Lfo2SweepKnob);
 	setParamKnob(synthv1::LFO2_ATTACK,  m_ui.Lfo2AttackKnob);
 	setParamKnob(synthv1::LFO2_DECAY,   m_ui.Lfo2DecayKnob);
@@ -652,6 +685,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// OUT2
 	setParamKnob(synthv1::OUT2_WIDTH,   m_ui.Out2WidthKnob);
 	setParamKnob(synthv1::OUT2_PANNING, m_ui.Out2PanningKnob);
+	setParamKnob(synthv1::OUT2_FXSEND,  m_ui.Out2FxSendKnob);
 	setParamKnob(synthv1::OUT2_VOLUME,  m_ui.Out2VolumeKnob);
 
 
@@ -678,10 +712,6 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DEL1_FEEDB, m_ui.Del1FeedbKnob);
 	setParamKnob(synthv1::DEL1_BPM,   m_ui.Del1BpmKnob);
 
-	QObject::connect(m_ui.Del1BpmKnob,
-		SIGNAL(valueChanged(float)),
-		SLOT(bpmSyncChanged()));
-
 	// Reverb
 	setParamKnob(synthv1::REV1_WET,   m_ui.Rev1WetKnob);
 	setParamKnob(synthv1::REV1_ROOM,  m_ui.Rev1RoomKnob);
@@ -874,9 +904,11 @@ void synthv1widget::updateParamEx ( synthv1::ParamIndex index, float fValue )
 		m_ui.Dco2Bandl2Knob->setEnabled(
 			synthv1_wave::Shape(int(fValue)) != synthv1_wave::Noise);
 		break;
-	case synthv1::DEL1_BPMSYNC:
-		if (fValue > 0.0f)
-			m_ui.Del1BpmKnob->setValue(0.0f);
+	case synthv1::DCF1_SLOPE:
+		m_ui.Dcf1TypeKnob->setEnabled(int(fValue) != 3); // !Formant
+		break;
+	case synthv1::DCF2_SLOPE:
+		m_ui.Dcf2TypeKnob->setEnabled(int(fValue) != 3); // !Formant
 		// Fall thru...
 	default:
 		break;
@@ -925,7 +957,7 @@ void synthv1widget::resetParams (void)
 			fValue = pKnob->defaultValue();
 		setParamValue(index, fValue);
 		updateParam(index, fValue);
-		m_params_ab[index] = fValue;
+		m_params_ab[i] = fValue;
 	}
 
 	m_ui.StatusBar->showMessage(tr("Reset preset"), 5000);
@@ -949,10 +981,10 @@ void synthv1widget::swapParams ( bool bOn )
 		synthv1widget_knob *pKnob = paramKnob(index);
 		if (pKnob) {
 			const float fOldValue = pKnob->value();
-			const float fNewValue = m_params_ab[index];
+			const float fNewValue = m_params_ab[i];
 			setParamValue(index, fNewValue);
 			updateParam(index, fNewValue);
-			m_params_ab[index] = fOldValue;
+			m_params_ab[i] = fOldValue;
 		}
 	}
 
@@ -986,7 +1018,7 @@ void synthv1widget::updateParamValues (void)
 		setParamValue(index, fValue, true);
 		updateParam(index, fValue);
 	//	updateParamEx(index, fValue);
-		m_params_ab[index] = fValue;
+		m_params_ab[i] = fValue;
 	}
 }
 
@@ -1001,7 +1033,7 @@ void synthv1widget::resetParamValues (void)
 		const float fValue = synthv1_param::paramDefaultValue(index);
 		setParamValue(index, fValue, true);
 		updateParam(index, fValue);
-		m_params_ab[index] = fValue;
+		m_params_ab[i] = fValue;
 	}
 }
 
@@ -1220,24 +1252,6 @@ void synthv1widget::updateDirtyPreset ( bool bDirtyPreset )
 }
 
 
-// Delay BPM change.
-void synthv1widget::bpmSyncChanged (void)
-{
-	if (m_iUpdate > 0)
-		return;
-
-	++m_iUpdate;
-	synthv1_ui *pSynthUi = ui_instance();
-	if (pSynthUi) {
-		const bool bBpmSync0 = (pSynthUi->paramValue(synthv1::DEL1_BPMSYNC) > 0.0f);
-		const bool bBpmSync1 = m_ui.Del1BpmKnob->isSpecialValue();
-		if ((bBpmSync1 && !bBpmSync0) || (!bBpmSync1 && bBpmSync0))
-			pSynthUi->setParamValue(synthv1::DEL1_BPMSYNC, (bBpmSync1 ? 1.0f : 0.0f));
-	}
-	--m_iUpdate;
-}
-
-
 // Param knob context menu.
 void synthv1widget::paramContextMenu ( const QPoint& pos )
 {
